#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-lua-engine
version:              0.4.1
visibility:           public
id:                   pandoc-lua-engine-0.4.1-I1uy8ob196B3p6AEX2CLLm
key:                  pandoc-lua-engine-0.4.1-I1uy8ob196B3p6AEX2CLLm
license:              GPL-2.0-or-later
copyright:            © 2006-2024 John MacFarlane, 2017-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  42a91178600c2c6f42943182a027ba3a
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Engine
    Text.Pandoc.Lua.Filter Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Module Text.Pandoc.Lua.Marshal.Chunks
    Text.Pandoc.Lua.Marshal.CommonState Text.Pandoc.Lua.Marshal.Context
    Text.Pandoc.Lua.Marshal.Format Text.Pandoc.Lua.Marshal.ImageSize
    Text.Pandoc.Lua.Marshal.LogMessage
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.Image
    Text.Pandoc.Lua.Module.JSON Text.Pandoc.Lua.Module.Log
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Run
    Text.Pandoc.Lua.SourcePos Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-lua-engine-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.4.1-I1uy8ob196B3p6AEX2CLLm
depends:
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG base-4.18.2.1
    bytestring-0.11.5.3 citeproc-0.8.1.2-4dnprXipYdHFfCTpymXqkT
    containers-0.6.7 crypton-1.0.5-AZiRYciVzaiGzchrza0W2Y
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    doclayout-0.5.0.1-cGRrJ3JDf93ijvc1J0CTX
    doctemplates-0.11.0.1-Eyf2boKkFT56Igns6tvBAe exceptions-0.10.7
    hslua-2.3.1-96RJ6DI2drD9ULuqtQtvHK
    hslua-module-doclayout-1.2.0.1-3soci6CupGz43vkWEARCEv
    hslua-module-path-1.1.1-BnWBXET17ShF0E6v1Eqwpi
    hslua-module-system-1.1.3-88JgxDb0BG8KhYzD6HJqYu
    hslua-module-text-1.1.1-G3fRGaf8Nm62r7abOp4rYA
    hslua-module-version-1.1.1-GJJn52bVwX1Dfy0ZlboOQ2
    hslua-module-zip-1.1.4-DKCXR0FnlWy9z6O3YAAfoD
    hslua-repl-0.1.2-H1D7XDo0hPqDmR54DRmxWy
    lpeg-1.1.0.1-G3X5d2ptexw4ZfYNvRk1yl mtl-2.3.1
    pandoc-3.6.1-FvrzCGtKuHZBeoTesKEjDo
    pandoc-lua-marshal-0.3.1-6HUqtmasfTP81cVEhyJWHR
    pandoc-types-1.23.1.1-513rNLDXitb6k4SgOFVT7b parsec-3.1.16.1
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

